@@ -1,6 +1,7 @@
 import os
 import pathlib
 import pytest
+import subprocess
 import shutil
 
 
@@ -14,6 +15,16 @@ if pytest.__version__ < "3.9":
         return pathlib.Path(tmpdir)
 
 
+@pytest.fixture(scope="session")
+def test_directory():
+    return pathlib.Path(__file__).parent
+
+
+@pytest.fixture(scope="session")
+def logs_directory(test_directory):
+    return test_directory / "logs"
+
+
 @pytest.fixture(scope="session", autouse=True)
 def session_home(tmpdir_factory):
     os.environ["HOME"] = str(tmpdir_factory.mktemp("HOME"))
@@ -27,10 +38,20 @@ def home(monkeypatch, tmp_path):
 
 
 @pytest.fixture(scope="session")
-def linux(tmpdir_factory):
-    src = pathlib.Path(__file__).parent / "fakelinux"
+def linux(test_directory, tmpdir_factory):
+    src = test_directory / "fakelinux"
     dst = tmpdir_factory.mktemp("source") / "linux"
     shutil.copytree(src, dst)
+    subprocess.check_call(["chmod", "-R", "ugo-w", str(dst)])
+    return dst
+
+
+@pytest.fixture
+def linux_rw(tmp_path):
+    src = pathlib.Path(__file__).parent / "fakelinux"
+    dst = tmp_path / "linux"
+    shutil.copytree(src, dst)
+    subprocess.check_call(["chmod", "-R", "u+w", str(dst)])
     return dst
 
 
