@@ -2,7 +2,6 @@ import os
 import re
 import subprocess
 import shutil
-import pathlib
 import pytest
 from tuxmake import __version__
 from tuxmake.build import Build
@@ -17,8 +16,8 @@ def home(tmpdir_factory):
 
 
 @pytest.fixture(scope="module")
-def linux(tmpdir_factory):
-    orig = pathlib.Path(__file__).parent / "fakelinux"
+def linux(test_directory, tmpdir_factory):
+    orig = test_directory / "fakelinux"
     source = tmpdir_factory.mktemp("source")
     _linux = source / "linux"
     shutil.copytree(orig, _linux)
@@ -137,3 +136,19 @@ class TestSystemMap:
 class TestTuxmake:
     def test_tuxmake_versino(self, build):
         assert build.metadata["tuxmake"]["version"] == __version__
+
+
+class TestResources:
+    def test_disk_space(self, build):
+        assert type(build.metadata["resources"]["disk_space"]) is int
+
+
+class TestHardware:
+    def test_cores(self, build):
+        assert type(build.metadata["hardware"]["cores"]) is int
+
+    def test_ram(self, build):
+        assert type(build.metadata["hardware"]["ram"]) is int
+
+    def test_free_disk_space(self, build):
+        assert type(build.metadata["hardware"]["free_disk_space"]) is int
