@@ -8,6 +8,7 @@ import subprocess
 import sys
 import time
 from tuxmake import __version__
+from tuxmake.logging import set_debug, debug
 from tuxmake.arch import Architecture, host_arch
 from tuxmake.toolchain import Toolchain, NoExplicitToolchain
 from tuxmake.wrapper import Wrapper
@@ -226,6 +227,7 @@ class Build:
         self.verbose = verbose
         self.quiet = quiet
         self.debug = debug
+        set_debug(self.debug)
 
         self.offline = False
 
@@ -233,6 +235,7 @@ class Build:
         self.__logger__ = None
         self.__status__ = {}
         self.__durations__ = {}
+        self.metadata_extractor = MetadataExtractor(self)
         self.metadata = OrderedDict()
         self.cmdline = CommandLine()
 
@@ -363,9 +366,9 @@ class Build:
                 self.log(quote_command_line(cmd))
                 stdout = logger
 
-        self.log_debug(f"Command: {final_cmd}")
+        debug(f"Command: {final_cmd}")
         if extra_env:
-            self.log_debug(f"Environment: {extra_env}")
+            debug(f"Environment: {extra_env}")
         try:
             with self.measure_duration("Command"):
                 process = subprocess.Popen(
@@ -394,7 +397,7 @@ class Build:
             duration = time.time() - start
             if metadata:
                 self.__durations__[metadata] = duration
-            self.log_debug(f"{name} finished in {duration} seconds.")
+            debug(f"{name} finished in {duration} seconds.")
 
     def expand_cmd_part(self, part):
         if part == "{make}":
@@ -445,10 +448,6 @@ class Build:
     def log(self, *stuff):
         subprocess.call(["echo"] + list(stuff), stdout=self.logger.stdin)
 
-    def log_debug(self, *stuff):
-        if self.debug:
-            print("D:", *stuff, file=sys.stderr)
-
     @property
     def make_args(self):
         return [f"{k}={v}" for k, v in self.makevars.items() if v]
@@ -472,14 +471,12 @@ class Build:
     def build(self, target):
         for dep in target.dependencies:
             if not self.status[dep].passed:
-                self.log_debug(
-                    f"Skipping {target.name} because dependency {dep} failed"
-                )
+                debug(f"Skipping {target.name} because dependency {dep} failed")
                 return BuildInfo("SKIP")
 
         for precondition in target.preconditions:
             if not self.run_cmd(precondition, stdout=subprocess.DEVNULL):
-                self.log_debug(f"Skipping {target.name} because precondition failed")
+                debug(f"Skipping {target.name} because precondition failed")
                 return BuildInfo("SKIP")
 
         target.prepare()
@@ -500,10 +497,9 @@ class Build:
 
     def check_artifacts(self, target):
         ret = True
-        for _, f in target.artifacts.items():
-            artifact = self.build_dir / f
+        for _, artifact in target.find_artifacts(self.build_dir):
             if not artifact.exists():
-                self.log(f"E: expected artifact {f} does not exist!")
+                self.log(f"E: expected artifact {artifact} does not exist!")
                 ret = False
         return ret
 
@@ -511,9 +507,8 @@ class Build:
         if not self.status[target.name].passed:
             return
         self.artifacts[target.name] = []
-        for origdest, origsrc in target.artifacts.items():
+        for origdest, src in target.find_artifacts(self.build_dir):
             dest = self.output_dir / origdest
-            src = self.build_dir / origsrc
             shutil.copy(src, Path(self.output_dir / dest))
             self.artifacts[target.name].append(origdest)
 
@@ -566,8 +561,8 @@ class Build:
         }
         self.metadata["tuxmake"] = {"version": __version__}
 
-        extractor = MetadataExtractor(self)
-        self.metadata.update(extractor.extract())
+        extracted = self.metadata_extractor.extract()
+        self.metadata.update(extracted)
 
     def save_metadata(self):
         with (self.output_dir / "metadata.json").open("w") as f:
@@ -605,13 +600,15 @@ class Build:
         build can be inspected though the `status`, `passed`, and `failed`
         properties.
         """
-        with self.measure_duration("Input validation", metadata="validate"):
-            self.validate()
-
-        with self.measure_duration("Preparation", metadata="prepare"):
-            self.prepare()
-
         try:
+            self.metadata_extractor.before_build()
+
+            with self.measure_duration("Input validation", metadata="validate"):
+                self.validate()
+
+            with self.measure_duration("Preparation", metadata="prepare"):
+                self.prepare()
+
             with self.go_offline():
                 with self.measure_duration("Build", metadata="build"):
                     self.build_all_targets()
