@@ -166,6 +166,11 @@ def build_parser(cls=argparse.ArgumentParser, **kwargs):
         action="store_true",
         help="Print support matrix (architectures x toolchains). Combine with --runtime to list support matrix for that particular runtime.",
     )
+    info.add_argument(
+        "--check-environment",
+        action="store_true",
+        help="Instead of running the build, just check if the build environment has the necessary tools for it. The check is run on the exact environment (e.g. container image) that the rest of the options would select cause to be selected.",
+    )
     info.add_argument(
         "-c",
         "--color",
@@ -267,7 +272,7 @@ class ReverseParser:
 
 
 class CommandLine:
-    ignore = ["targets", "jobs", "output_dir", "build_dir"]
+    ignore = ["targets", "jobs", "output_dir", "build_dir", "check_environment"]
 
     def __init__(self):
         self.parser = build_parser(cls=ReverseParser)
@@ -312,7 +317,7 @@ _tuxmake() {{
             COMPREPLY=($(compgen -W "{runtimes}" -- ${{cur}}))
             ;;
         *)
-            COMPREPLY=($(compgen -W "{options}" -- ${{cur}}))
+            COMPREPLY=($(compgen -W "{options} $(ls -1 ${{XDG_CONFIG_HOME:-~/.config}}/tuxmake/ 2>/dev/null | sed -e '/^default$/d; s/^/@/')" -- ${{cur}}))
             ;;
     esac
 }}
